@@ -62,7 +62,7 @@ considered public as object names -- the API of the formatter objects is
 still considered an implementation detail.)
 """
 
-__version__ = '1.1.1'
+__version__ = '1.1.2'
 __all__ = [
     'ArgumentParser',
     'ArgumentError',
@@ -1620,6 +1620,7 @@ class ArgumentParser(_AttributeHolder, _ActionsContainer):
     """Object for parsing command line strings into Python objects.
 
     Keyword Arguments:
+        - input_list -- A list of string args to parse (default: sys.argv)
         - prog -- The name of the program (default: sys.argv[0])
         - usage -- A usage message (default: auto-generated from arguments)
         - description -- A description of what the program does
@@ -1633,6 +1634,7 @@ class ArgumentParser(_AttributeHolder, _ActionsContainer):
         - conflict_handler -- String indicating how to handle conflicts
         - add_help -- Add a -h/-help option
         - allow_abbrev -- Allow long options to be abbreviated unambiguously
+        - exit_on_error -- quit() on error, or raise ArgumentException (default: True)
     """
 
     def __init__(self,
@@ -1648,7 +1650,8 @@ class ArgumentParser(_AttributeHolder, _ActionsContainer):
                  argument_default=None,
                  conflict_handler='error',
                  add_help=True,
-                 allow_abbrev=True):
+                 allow_abbrev=True,
+                 exit_on_error=True):
 
         superinit = super(ArgumentParser, self).__init__
         superinit(description=description,
@@ -1668,6 +1671,7 @@ class ArgumentParser(_AttributeHolder, _ActionsContainer):
         self.fromfile_prefix_chars = fromfile_prefix_chars
         self.add_help = add_help
         self.allow_abbrev = allow_abbrev
+        self.exit_on_error = exit_on_error
 
         add_group = self.add_argument_group
         self._positionals = add_group(_('positional arguments'))
@@ -2507,7 +2511,8 @@ class ArgumentParser(_AttributeHolder, _ActionsContainer):
     def exit(self, status=0, message=None):
         if message:
             self._print_message(message, _sys.stderr)
-        _sys.exit(status)
+        if self.exit_on_error:
+            _sys.exit(status)
 
     def error(self, message):
         """error(message: string)
@@ -2520,4 +2525,8 @@ class ArgumentParser(_AttributeHolder, _ActionsContainer):
         """
         self.print_usage(_sys.stderr)
         args = {'prog': self.prog, 'message': message}
-        self.exit(2, _('%(prog)s: error: %(message)s\n') % args)
+
+        if self.exit_on_error:
+            self.exit(2, _('%(prog)s: error: %(message)s\n') % args)
+        else:
+            raise ArgumentError(self, message)
